#include <hmg.ch>
#include <common.ch>

********************************************************************************
**  Function: selectDateRange()                                               **
**   Purpose: Generic date selection routine.                                 **
**                                                                            **
** Called By: Generic routine.                                                **
**                                                                            **
**    Syntax: selectDateRange( <nExp1>, <nExp2> ) --> <aExpression>           **
**                                                                            **
** Arguments: nExp1 specifies the windows objects contents to be loaded.      **
**                  The default value is 1.                                   **
**            nExp2 specifies the Maximum width of Textbox object control.    **
**                  The default value is 7.                                   **
**            If either one or both parameters are not received the program   **
**            assumes their default value.                                    **
**                                                                            **
**   Returns: Single dimensional array in the following format:               **
**              { <Date From>, <Date To>, <Option Selection>, <Code> } where  **
**              <Date From> is equivalent to Starting Date                    **
**              <Date To>   is equivalent to Ending Date                      **
**              <Option Selection> is the choice made by user                 **
**              <Code>      is the code given on the text box provided.       **
**                                                                            **
**              It also returns nil when none is selected or Cancel/Close     **
**              button is pressed or ESCAPE key was used to terminate the     **
**              Dialog box.                                                   **
**                                                                            **
**  Note: Third parameter has been added for title. TODO update docs and      **
**        do code refactoring on this function to tidy it up.                 **
**             September 15, 2012 11:34:33 PM                                 **
**                                                                            **
********************************************************************************
function selectDateRange( nhWindType, nTboxMaxWidth, cWinTitle )

   LOCAL aDateOptions_ := { "Date Today", "Specific Date", "Month-to-date", "Year-to-date", "Date Range" }
   LOCAL aRetVal_ := NIL

   DEFAULT nhWindtype    TO 1
   DEFAULT nTboxMaxWidth TO 7
   DEFAULT cWinTitle     TO "Select date"

   IF ISWINDOWDEFINED( hWndDialogDate ) .OR. ISWINDOWACTIVE( "hWndDialogDate" )
      DOMETHOD( "hWndDialogDate", "Restore" )
      DOMETHOD( "hWndDialogDate", "Setfocus" )
      RETURN NIL
   ENDIF

   IF nhWindType = 1
      DEFINE WINDOW hWndDialogDate;
         AT 0,0;
         WIDTH 309 HEIGHT 254;
         TITLE cWinTitle;
         ICON "MAINICON";
         NOMINIMIZE NOMAXIMIZE NOSIZE;
         ON INTERACTIVECLOSE NIL;
         FONT "Arial" SIZE 9
   
         @  10, 10 FRAME frOption OF hWndDialogDate CAPTION "Options:"; 
            WIDTH  110 HEIGHT 160 FONT "Arial" SIZE 9 BACKCOLOR NIL FONTCOLOR NIL OPAQUE
   
         @  10,130 FRAME frDate OF hWndDialogDate CAPTION "Date"; 
            WIDTH  160 HEIGHT 160 FONT "Arial" SIZE 9 BACKCOLOR NIL FONTCOLOR NIL OPAQUE
   
         @  53,140 LABEL lblFrom OF hWndDialogDate VALUE "Fro&m:"; 
            ACTION Nil WIDTH  35 HEIGHT 14 FONT "Arial" SIZE 9
   
         @  50,180 DATEPICKER dpkFrom OF hWndDialogDate VALUE CTOD(" / / ");
            WIDTH  95 HEIGHT 24 FONT "Arial" SIZE 9 UPDOWN
            
         @ 113,140 LABEL lblTo OF hWndDialogDate VALUE "&To:"; 
            ACTION Nil WIDTH  35 HEIGHT 14 FONT "Arial" SIZE 9
            
         @ 110,180 DATEPICKER dpkTo OF hWndDialogDate VALUE CTOD(" / / ");
            WIDTH  95 HEIGHT 24 FONT "Arial" SIZE 9 UPDOWN
            
         @  28, 20  RADIOGROUP rdgOptions  OF hWndDialogDate;
            OPTIONS aDateOptions_;
            VALUE 1 WIDTH  100 FONT "Arial" SIZE 9 ON CHANGE daterangeChange()
            
        @ 180, 90 BUTTON btnOK OF hWndDialogDate CAPTION "&Ok"; 
            ACTION ( aRetVal_ := { hWndDialogDate.dpkFrom.Value, hWndDialogDate.dpkTo.Value, ;
               hWndDialogDate.rdgOptions.Value }, ThisWindow.Release ) ;
            WIDTH  100 HEIGHT 28
            
         @ 180,190 BUTTON btnGUIClose OF hWndDialogDate CAPTION "&Cancel"; 
            ACTION ThisWindow.Release;
            WIDTH  100 HEIGHT 28
      END WINDOW

   ELSEIF nhWindType = 2
      DEFINE WINDOW hWndDialogDate;
         AT 0,0;
         WIDTH 309 HEIGHT 254;
         TITLE cWinTitle;
         ICON "MAINICON";
         NOMINIMIZE NOMAXIMIZE NOSIZE;
         ON INTERACTIVECLOSE NIL;
         FONT "Arial" SIZE 9
         
         @  10, 10 FRAME frOption OF hWndDialogDate CAPTION "Options:"; 
            WIDTH  110 HEIGHT 160 FONT "Arial" SIZE 9 BACKCOLOR NIL FONTCOLOR NIL OPAQUE
         
         @  10,130 FRAME frDate OF hWndDialogDate CAPTION "Date"; 
            WIDTH  160 HEIGHT 14 FONT "Arial" SIZE 9 BACKCOLOR NIL FONTCOLOR NIL OPAQUE

         @ 100,130 FRAME frCode OF hWndDialogDate CAPTION "Vendor ID:" ;
            WIDTH 160 HEIGHT 70 FONT "ARIAL" SIZE 9 BACKCOLOR NIL FONTCOLOR NIL OPAQUE

         @  33,140 LABEL lblFrom OF hWndDialogDate VALUE "Fro&m:"; 
            ACTION Nil WIDTH  35 HEIGHT 14 FONT "Arial" SIZE 9
         
         @  30,180 DATEPICKER dpkFrom OF hWndDialogDate VALUE CTOD(" / / ");
            WIDTH  95 HEIGHT 24 FONT "Arial" SIZE 9 UPDOWN
            
         @  64,140 LABEL lblTo OF hWndDialogDate VALUE "&To:"; 
            ACTION Nil WIDTH  35 HEIGHT 14 FONT "Arial" SIZE 9
            
         @  60,180 DATEPICKER dpkTo OF hWndDialogDate VALUE CTOD(" / / ");
            WIDTH  95 HEIGHT 24 FONT "Arial" SIZE 9 UPDOWN
            
         @  28, 20  RADIOGROUP rdgOptions  OF hWndDialogDate;
            OPTIONS aDateOptions_;
            VALUE 1 WIDTH  100 FONT "Arial" SIZE 9 ON CHANGE daterangeChange()
         
         @ 130,140 TEXTBOX txbCode OF hWndDialogDate HEIGHT 24 VALUE "" WIDTH 100 FONT "ARIAL" SIZE 9 TOOLTIP "";
            MAXLENGTH nTboxMaxWidth ON LOSTFOCUS NIL

         @ 129,242 BUTTON btnFind OF hWndDilalogDate CAPTION "Find";
           ; //ACTION ( hWndDialogDate.txbCode.Value := daterangeBtnFind() ) WIDTH 45 HEIGHT 26;
           ACTION MSGINFO( "You can add your UDF here to pick-up a code from a dbf file.", "Test" ) WIDTH 45 HEIGHT 26
         
         @ 180, 90 BUTTON btnOK OF hWndDialogDate CAPTION "&Ok"; 
            ACTION ( aRetVal_ := { hWndDialogDate.dpkFrom.Value, hWndDialogDate.dpkTo.Value, ;
               hWndDialogDate.rdgOptions.Value, hWndDialogDate.txbCode.Value }, ThisWindow.Release ) ;
            WIDTH  100 HEIGHT 28
            
         @ 180,190 BUTTON btnGUIClose OF hWndDialogDate CAPTION "&Cancel"; 
            ACTION ThisWindow.Release;
            WIDTH  100 HEIGHT 28
      END WINDOW
   ENDIF
   hWndDialogDate.lblFrom.Value := "For"
   hWndDialogDate.lblTo.Enabled := .F.
   hWndDialogDate.dpkTo.Enabled := .F.
   hWndDialogDate.Center
   hWndDialogDate.Activate
   RETURN aRetVal_



********************************************************************************
**  Function: daterangeChange()                                               **
**   Purpose: Support routine of selectDateRange()                            **
**                                                                            **
** Called By: selectDateRange()                                               **
**                                                                            **
**    Syntax: daterangeChange()                                               **
**                                                                            **
** Arguments: None.                                                           **
**                                                                            **
**   Returns: NIL                                                             **
**                                                                            **
**     Notes:                                                                 **
********************************************************************************
static function daterangeChange()

   LOCAL nOptionValue := hWndDialogDate.rdgOptions.Value

   DO CASE
      **--> today's date
      CASE nOptionValue = 1
         hWndDialogDate.lblFrom.Value := "For"
         hWndDialogDate.lblTo.Enabled := .F.
         hWndDialogDate.dpkTo.Enabled := .F.
         hWndDialogDate.dpkFrom.Value := DATE()
         hWndDialogDate.dpkTo.Value   := hWndDialogDate.dpkFrom.Value

      **--> specific date only
      CASE nOptionValue = 2
         hWndDialogDate.lblFrom.Value := "For"
         hWndDialogDate.lblTo.Enabled := .F.
         hWndDialogDate.dpkTo.Enabled := .F.
         hWndDialogDate.dpkFrom.Value := DATE()
         hWndDialogDate.dpkTo.Value   := hWndDialogDate.dpkFrom.Value

      **--> Month-To-Date
      CASE nOptionValue = 3
         hWndDialogDate.lblFrom.Value := "From"
         hWndDialogDate.lblTo.Enabled := .T.
         hWndDialogDate.dpkTo.Enabled := .T.
   
         hWndDialogDate.dpkFrom.Value := BOM( DATE() )
         hWndDialogDate.dpkTo.Value   := DATE()

      **--> Year-To-Date
      CASE nOptionValue = 4
         hWndDialogDate.lblFrom.Value := "From"
         hWndDialogDate.lblTo.Enabled := .T.
         hWndDialogDate.dpkTo.Enabled := .T.
   
         hWndDialogDate.dpkFrom.Value := BOY( DATE() )
         hWndDialogDate.dpkTo.Value   := DATE()

      **--> Date Range
      CASE nOptionValue = 5
         hWndDialogDate.lblFrom.Value := "From"
         hWndDialogDate.lblTo.Enabled := .T.
         hWndDialogDate.dpkTo.Enabled := .T.
   
         hWndDialogDate.dpkFrom.Value := BOY( hWndDialogDate.dpkFrom.Value )
         hWndDialogDate.dpkTo.Value   := EOY( hWndDialogDate.dpkFrom.Value )
   ENDCASE
   RETURN NIL